@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2008 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,10 @@
 
 #include "food.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void add_foods(int);
 void new_recipe_show(void);
 void get_recipe_qty(float *result);
@@ -37,4 +41,8 @@ void guess_recipe();
 void solve_it(int, int *, int *, int *);
 void modify_servings(void);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
