@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -104,14 +104,13 @@ while (max > 0)
  if (strncmp(inbuf,"c",1) == 0)
   {
   if (options.screen != 0) continue;
-  if (!options.locknuts[ENERC_KCAL])
-   {
-   newcal = food_work.nutrient[ENERC_KCAL];
-   options.abnuts[FAT] = 0;
-   options.abnuts[FAMS] = 0;
-   if (options.abnuts[PROCNT]) options.pccarb = 0;
-   auto_cal(&newcal,1);
-   }
+  if (options.locknuts[ENERC_KCAL]) continue;
+  
+  newcal = food_work.nutrient[ENERC_KCAL];
+  if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
+  if (!options.locknuts[FAMS]) options.abnuts[FAMS] = 0;
+  if (options.abnuts[PROCNT]) options.pccarb = 0;
+  auto_cal(&newcal,1);
   } 
  else if (strncmp(inbuf,"d",1) == 0) screen();
  else if (strncmp(inbuf,"p",1) == 0) screen_previous();
@@ -143,6 +142,8 @@ while (max > 0)
   {
   if (options.screen != 0) continue;
   restore_defaults(0);
+  newcal = food_work.nutrient[ENERC_KCAL];
+  if (options.locknuts[FAT]) auto_cal(&newcal,1);
   }
  else if (strncmp(inbuf,"n",1) == 0)
   {
@@ -247,9 +248,17 @@ while (max > 0)
      if (strstr(food_ptr->name,"AK NATIVE") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"NAVAJO") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"SHOSHONE BANNOCK") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"PACIFIC NORTHWEST INDIANS") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"INST BRKFST PDR") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"INSTANT BREAKFAST") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"ENSURE") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"PROTEIN SUPPLEMENT") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"SOY PROTEIN ISOLATE") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"SOY PROTEIN CONC") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"MEAT EXTENDER") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"VITAMIN AND MINERAL FORTIFIED") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"EGG MIX,USDA COMMODITY") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"INDUSTRIAL") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"MEATLESS") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"MARGARINE") != NULL) high_grams = 14;
      if (food_ptr->fdgrp == 2 || food_ptr->fdgrp == 3 || food_ptr->fdgrp == 8 || food_ptr->fdgrp == 14 || food_ptr->fdgrp == 19 || food_ptr->fdgrp == 25) serving_ratio_abacus[abacuscount] = 0;
