@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,13 +35,14 @@ char nutdir1[]=".nutdb";
 char nutdir1[]=NUTDIR ;
 #endif
 
-char USDAjoined1[] = "sr22.nut";
+char USDAjoined1[] = USDAVERSIONLC".nut";
 char globalFOOD1[] = "FOOD_DES.txt";
 char globalNUT1[] = "NUT_DATA.txt";
 char globalWEIGHT1[] = "WEIGHT.txt";
 char weightlib1[] = "WEIGHT.lib";
 char WLOG1[] = "WLOG.txt";
 char WLOGold1[] = "WLOG.old";
+char WLOGaux1[] = "WLOG.aux";
 char localFOOD1[] = "FOOD_DES.txt";
 char localNUT1[] = "NUT_DATA.txt";
 char localWEIGHT1[] = "WEIGHT.txt";
@@ -62,6 +63,7 @@ char globalWEIGHT[2000];
 char weightlib[2000];
 char WLOG[2000];
 char WLOGold[2000];
+char WLOGaux[2000];
 char localFOOD[2000];
 char localNUT[2000];
 char localWEIGHT[2000];
@@ -80,14 +82,12 @@ char subuser[2000];
 
 int mealdb_mealsperday;
 
-FILE *fp;
+FILE *fp, *fpaux;
 
 void read_food_files()
 {
- if (version(0) < 10) remove(optionsfile);
  read_joined_db(USDAjoined);
- if (version(0) == 10 && version(1) < 7) read_options_db(1);
- else read_OPTIONS(1);
+ read_OPTIONS(1);
  read_FOOD(globalFOOD);
  read_NUT(globalNUT);
  read_WEIGHT(globalWEIGHT);
@@ -101,7 +101,6 @@ void read_food_files()
  write_food_db();
  write_meal_db();
  write_theusual_db();
- read_OPTIONS(0);
  write_OPTIONS();
 }
 
@@ -708,9 +707,15 @@ fprintf(fp,"%d^%f^\n",CARBCALPERGM,options.carbcalpergm);
 fprintf(fp,"%d^%f^\n",FATCALPERGM,options.fatcalpergm);
 fprintf(fp,"%d^%f^\n",FATTYACIDFACTOR,options.fattyacidfactor);
 fprintf(fp,"%d^%f^\n",N6HUFA,options.n6hufa);
+fprintf(fp,"%d^%f^\n",ALAFACTOR,options.alafactor);
 fprintf(fp,"%d^%f^\n",EPADHAMAX,options.epadhamax);
 fprintf(fp,"%d^%d^\n",DEFANALANAL,options.defanalanal);
 fprintf(fp,"%d^%d^\n",DEFANALREC,options.defanalrec);
+fprintf(fp,"%d^%f^\n",LASTWLW,options.lastwlw);
+fprintf(fp,"%d^%f^\n",LASTWLBFP,options.lastwlbfp);
+fprintf(fp,"%d^%f^\n",LASTWLDATE,options.lastwldate);
+fprintf(fp,"%d^%f^\n",FATTARGET,options.fattarget);
+fprintf(fp,"%d^%f^\n",LEANTARGET,options.leantarget);
 for (i = 1; i <= DV_COUNT; i++)
  {
  switch (DVMap[i])
@@ -741,47 +746,20 @@ for (i = 1; i <= DV_COUNT; i++)
 fclose(fp);
 }
 
-void read_options_db(int dontwrite)
-{
-int block, need_to_find_next_recipe = 0;
-struct food *food_ptr = &food_root;
-initialize_options();
-if ((fp = fopen(optionsfile,"rb")) == NULL) 
- {
- write_OPTIONS();
- if (! dontwrite) need_to_find_next_recipe = 1;
- }
-if ((fp = fopen(optionsfile,"rb")) == NULL) 
- {
- printf("Can't open options database \"%s\" to read.\n",optionsfile);
- printf("Press <enter> to continue...");
- block = get_int();
- abort();
- }
-fread(&options,sizeof(struct opt),1,fp);
-fclose(fp);
-remove(optionsfile);
-options.temp_meal_root = &meal_root;
-auto_cal(&options.abnuts[ENERC_KCAL],0);
-delete_meals(options.delopt);
-if (! dontwrite) write_meal_db();
-if (need_to_find_next_recipe) while (food_ptr->next != NULL)
- {
- food_ptr = food_ptr->next;
- if (food_ptr->ndb_no >= options.next_recipe) options.next_recipe = food_ptr->ndb_no + 1;
- }
-}
-
 void read_OPTIONS(int dontwrite)
 {
-int block, need_to_find_next_recipe = 0, field;
+int block, field;
 char buffer[101], valbuf1[51], valbuf2[51];
 struct food *food_ptr = &food_root;
 initialize_options();
 if ((fp = fopen(localOPTIONS,"rb")) == NULL) 
  {
+ while (food_ptr->next != NULL)
+  {
+  food_ptr = food_ptr->next;
+  if (food_ptr->ndb_no >= options.next_recipe) options.next_recipe = food_ptr->ndb_no + 1;
+  }
  write_OPTIONS();
- if (! dontwrite) need_to_find_next_recipe = 1;
  }
 if ((fp = fopen(localOPTIONS,"rb")) == NULL) 
  {
@@ -829,12 +807,24 @@ while (fgets(buffer,100,fp) != NULL)
                         break;
   case N6HUFA          : options.n6hufa = atof(valbuf1);
                         break;
+  case ALAFACTOR       : options.alafactor = atof(valbuf1);
+                        break;
   case EPADHAMAX       : options.epadhamax = atof(valbuf1);
                         break;
   case DEFANALANAL     : options.defanalanal = atoi(valbuf1);
                         break;
   case DEFANALREC      : options.defanalrec = atoi(valbuf1);
                         break;
+  case LASTWLW         : options.lastwlw = atof(valbuf1);
+                        break;
+  case LASTWLBFP       : options.lastwlbfp = atof(valbuf1);
+                        break;
+  case LASTWLDATE      : options.lastwldate = atof(valbuf1);
+                        break;
+  case FATTARGET       : options.fattarget = atof(valbuf1);
+                        break;
+  case LEANTARGET      : options.leantarget = atof(valbuf1);
+                        break;
   case OPT_CHO_NONFIB : options.abnuts[CHO_NONFIB] = atof(valbuf1);
                         options.locknuts[CHO_NONFIB] = atoi(valbuf2);
                         break;
@@ -872,16 +862,12 @@ options.temp_meal_root = &meal_root;
 auto_cal(&options.abnuts[ENERC_KCAL],0);
 delete_meals(options.delopt);
 if (! dontwrite) write_meal_db();
-if (need_to_find_next_recipe) while (food_ptr->next != NULL)
- {
- food_ptr = food_ptr->next;
- if (food_ptr->ndb_no >= options.next_recipe) options.next_recipe = food_ptr->ndb_no + 1;
- }
 }
 
 void read_WLOG(int *n, int *fatn, float *weightslope, float *fatslope)
 {
 char buffer[101];
+char *day[] = {"Sun","Mon","Tue","Wed","Thu","Fri","Sat"};
 float weight, bf, stardate;
 float fat;
 float sumweightx = 0, sumweighty = 0, sumweightxx = 0, sumweightxy = 0;
@@ -889,12 +875,22 @@ float sumfatx = 0, sumfaty = 0, sumfatxx = 0, sumfatxy = 0;
 
 *n = 0;
 *fatn = 0;
+options.fattarget = 0;
+options.leantarget = 0;
 if ((fp = fopen(WLOG,"rb")) == NULL) return;
+if ((fpaux = fopen(WLOGaux,"wb")) == NULL)
+ {
+ printf("Can't open weight log auxiliary file %s to write.\n",WLOGaux);
+ abort();
+ }
 while (fgets(buffer,100,fp) != NULL)                   
  {
  weight   = atof(strtok(buffer," "));
  bf       = atof(strtok(NULL," "));
  stardate = atof(strtok(NULL," "));
+ options.lastwlw = weight;
+ options.lastwlbfp = bf;
+ options.lastwldate = stardate;
  (*n)++;
  sumweightx += stardate;
  sumweightxx += stardate * stardate;
@@ -904,40 +900,51 @@ while (fgets(buffer,100,fp) != NULL)
  if (fat > 0) 
   {
   (*fatn)++;
-   sumfatx += stardate;
-   sumfatxx += stardate * stardate;
-   sumfaty += fat;
-   sumfatxy += stardate * fat;
+  sumfatx += stardate;
+  sumfatxx += stardate * stardate;
+  sumfaty += fat;
+  sumfatxy += stardate * fat;
+  if (*fatn == 1)
+   {
+   options.fattarget = fat;
+   options.leantarget = weight - fat;
+   }
   }
+ fprintf(fpaux,"%3.1f %2.1f %3g %s lean_mass=%2.2f fat_mass=%2.2f\n",weight,bf,stardate,day[(int)stardate % 7],weight-fat,fat);
  }
 fclose(fp);
+fclose(fpaux);
 *weightslope = (sumweightxy - (sumweightx * sumweighty / *n)) / (sumweightxx - (sumweightx * sumweightx / *n));
-*weightslope = (float) (int) (1000 * *weightslope);
-*weightslope /= 1000;
 if (*fatn > 1) 
  {
  *fatslope = (sumfatxy - (sumfatx * sumfaty / *fatn)) / (sumfatxx - (sumfatx * sumfatx / *fatn));
  *fatslope = (float) (int) (1000 * *fatslope);
  *fatslope /= 1000;
  }
+*weightslope = (float) (int) (1000 * *weightslope);
+*weightslope /= 1000;
 }
 
 void write_WLOG(float *weight, float *bf, float *stardate)
 {
 char buffer[128];
 int block, c;
-if (*weight == 0)
- {
- rename(WLOG,WLOGold);
- return;
- }
+if (*weight == 0) rename(WLOG,WLOGold);
 if ((fp = fopen(WLOG,"ab")) == NULL)
  {
  printf("Can't open weight log file %s to append.\n",WLOG);
  abort();
  }
-sprintf(buffer,"%g %g %g\n",*weight,*bf,*stardate);
-c = strlen(buffer);
+if (*weight == 0)
+ {
+ sprintf(buffer,"%g %g %g\n",options.lastwlw,options.lastwlbfp,options.lastwldate);
+ c = strlen(buffer);
+ }
+else
+ {
+ sprintf(buffer,"%g %g %g\n",*weight,*bf,*stardate);
+ c = strlen(buffer);
+ }
 if ((block = fwrite(buffer,c,1,fp)) != 1)
  {
  printf("Cannot write to the disk.  Aborting...\n");
@@ -954,13 +961,14 @@ strcpy(subuser,sub);
  mkdir (nutdir, 0700 );
  sprintf(nutdirsubuser,"%s/%s","NUTDB",subuser);
  mkdir (nutdirsubuser, 0700 );
- sprintf(USDAjoined,"%s/%s","NUTSR22",USDAjoined1);
- sprintf(globalFOOD,"%s/%s","NUTSR22",globalFOOD1);
- sprintf(globalNUT,"%s/%s","NUTSR22",globalNUT1);
- sprintf(globalWEIGHT,"%s/%s","NUTSR22",globalWEIGHT1);
- sprintf(weightlib,"%s/%s","NUTSR22",weightlib1);
+ sprintf(USDAjoined,"%s/%s","NUT"USDAVERSION,USDAjoined1);
+ sprintf(globalFOOD,"%s/%s","NUT"USDAVERSION,globalFOOD1);
+ sprintf(globalNUT,"%s/%s","NUT"USDAVERSION,globalNUT1);
+ sprintf(globalWEIGHT,"%s/%s","NUT"USDAVERSION,globalWEIGHT1);
+ sprintf(weightlib,"%s/%s","NUT"USDAVERSION,weightlib1);
  sprintf(WLOG,"%s/%s","NUTDB",WLOG1);
  sprintf(WLOGold,"%s/%s","NUTDB",WLOGold1);
+ sprintf(WLOGaux,"%s/%s","NUTDB",WLOGaux1);
  sprintf(localFOOD,"%s/%s/%s","NUTDB",subuser,localFOOD1);
  sprintf(localNUT,"%s/%s/%s","NUTDB",subuser,localNUT1);
  sprintf(localWEIGHT,"%s/%s/%s","NUTDB",subuser,localWEIGHT1);
@@ -984,6 +992,7 @@ sprintf(globalWEIGHT,"%s/%s",FOODDIR,globalWEIGHT1);
 sprintf(weightlib,"%s/%s",FOODDIR,weightlib1);
 sprintf(WLOG,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,WLOG1);
 sprintf(WLOGold,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,WLOGold1);
+sprintf(WLOGaux,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,WLOGaux1);
 sprintf(localFOOD,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localFOOD1);
 sprintf(localNUT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localNUT1);
 sprintf(localWEIGHT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localWEIGHT1);
@@ -996,38 +1005,9 @@ sprintf(optionsfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,optionsfile1);
 sprintf(localOPTIONS,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localOPTIONS1);
 sprintf(versionfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,versionfile1);
 sprintf(oldversionfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,oldversionfile1);
-check_version_file();
 #endif
 }
 
-void check_version_file()
-{
-char release_string[9];
-int majrelease, minrelease, majreleasedot, minreleasedot;
-if ((fp = fopen(oldversionfile,"rb")) == NULL) return;
-fread(&release_string,8,1,fp);
-fclose(fp);
-majreleasedot = atoi(strtok(release_string,"."));
-minreleasedot = atoi(strtok(NULL,"."));
-remove(oldversionfile);
-if ((fp = fopen(versionfile,"rb")) == NULL)
- {
- if ((fp = fopen(versionfile,"wb")) == NULL) return;
- fprintf(fp,"%d.%d",majreleasedot,minreleasedot);
- fclose(fp);
- return;
- }
-fread(&release_string,8,1,fp);
-fclose(fp);
-majrelease = atoi(strtok(release_string,"."));
-minrelease = atoi(strtok(NULL,"."));
-if (majreleasedot < majrelease) return;
-if (majreleasedot == majrelease && minreleasedot <= minrelease) return;
-if ((fp = fopen(versionfile,"wb")) == NULL) return;
-fprintf(fp,"%d.%d",majreleasedot,minreleasedot);
-fclose(fp);
-}
-
 int version(int level)
 {
 char release_string[128];
