@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,14 +23,20 @@
 #define DB_H
 
 #define MAJVERSION 15
-#define MINVERSION 2
-#define VERSIONQ "15.2"
+#define MINVERSION 8
+#define VERSIONQ "15.8"
+#define USDAVERSION "SR22"
+#define USDAVERSIONLC "sr22"
 
 #include <stdio.h>
 #include "food.h"
 
 extern char subuser[];
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void read_food_files(void);
 void read_joined_db(char *);
 void read_FOOD(char *);
@@ -46,14 +52,16 @@ void write_theusual_db(void);
 void write_OPTIONS(void);
 void write_recipe(struct food *);
 void write_serving(struct food *);
-void read_options_db(int);
 void read_OPTIONS(int);
 void read_WLOG(int *, int *, float *, float *);
 void write_WLOG(float *, float *, float *);
 void make_filenames(char *);
 int version(int);
 void write_version(void);
-void check_version_file(void);
 void meal_export(void);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
