@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -106,6 +106,7 @@ void initializations()
 int c;
 NoData = atof("-0");
 test_signsense(&NoData);
+initialize_options();
 for (c=0; c < NUTRIENT_COUNT; c++) DVBase[c] = 0;
 
 DVBase[ENERC_KCAL] = 2000;
@@ -138,10 +139,10 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 4.44;
-DVBase[AA] = 0.2;
+DVBase[LA] = 9;
+DVBase[AA] = 0.16;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 2.667;
+DVBase[ALA] = DVBase[LA] / options.alafactor;
 DVBase[EPA] = 0.3;
 DVBase[DHA] = 0.3;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
@@ -166,14 +167,6 @@ food_ptr->next = new_food;
 return foodnum;
 }
 
-void order_new_food_already_sorted()
-{
-struct food *food_ptr = &food_root;
-while (food_ptr->next != NULL) food_ptr = food_ptr->next;
-new_food->next = NULL;
-food_ptr->next = new_food;
-}
-
 int namestrcmp(char *name1, char *name2)
 {
 char namebuf1[61], namebuf2[61];
@@ -928,7 +921,7 @@ m->next = po;
 void compute_derived_fields(struct food *food_ptr)
 {
 float ratio, realcal, alcCalFactor = 6.93;;
-food_ptr->nutrient[VITE] = (food_ptr->nutrient[VITE_ADDED] / 0.45) + ((food_ptr->nutrient[TOCPHA] - food_ptr->nutrient[VITE_ADDED]) / 0.67);
+if (!test_for_negative_zero(&food_ptr->nutrient[VITE_ADDED]) || !test_for_negative_zero(&food_ptr->nutrient[VITE]) || !test_for_negative_zero(&food_ptr->nutrient[TOCPHA])) food_ptr->nutrient[VITE] = (food_ptr->nutrient[VITE_ADDED] / 0.45) + ((food_ptr->nutrient[TOCPHA] - food_ptr->nutrient[VITE_ADDED]) / 0.67);
 food_ptr->nutrient[LA] = food_ptr->nutrient[F18D2CN6] > 0 ? food_ptr->nutrient[F18D2CN6] : food_ptr->nutrient[F18D2] - food_ptr->nutrient[F18D2T] - food_ptr->nutrient[F18D2TT] - food_ptr->nutrient[F18D2I] - food_ptr->nutrient[F18D2CLA];
 if (food_ptr->nutrient[LA] == 0 && test_for_negative_zero(&food_ptr->nutrient[F18D2])) food_ptr->nutrient[LA] = NoData;
 if (food_ptr->nutrient[LA] < 0) food_ptr->nutrient[LA] = 0;
@@ -977,8 +970,11 @@ if ( food_ptr->prot_cal_factor == 0 && food_ptr->fat_cal_factor == 0 && food_ptr
 food_ptr->nutrient[PROT_KCAL] = food_ptr->prot_cal_factor * food_ptr->nutrient[PROCNT];
 food_ptr->nutrient[FAT_KCAL] = food_ptr->fat_cal_factor * food_ptr->nutrient[FAT];
 food_ptr->nutrient[CHO_KCAL] = food_ptr->cho_cal_factor * food_ptr->nutrient[CHOCDF];
-food_ptr->nutrient[CHO_NONFIB] = food_ptr->nutrient[CHOCDF] - food_ptr->nutrient[FIBTG];
-if (food_ptr->nutrient[CHO_NONFIB] < 0) food_ptr->nutrient[CHO_NONFIB] = 0;
+if (!test_for_negative_zero(&food_ptr->nutrient[CHOCDF]))
+ {
+ food_ptr->nutrient[CHO_NONFIB] = food_ptr->nutrient[CHOCDF] - food_ptr->nutrient[FIBTG];
+ if (food_ptr->nutrient[CHO_NONFIB] < 0) food_ptr->nutrient[CHO_NONFIB] = 0;
+ }
 }
 
 char *format_serving(char *buffer, float *ratio, struct food *food_ptr)
@@ -1000,7 +996,7 @@ float answer;
 printf("%f %f %f %f %f\n",p3,p6,h3,h6,o);
 exit(0);
 */  
-if (p3 == 0 && p6 == 0 && h3 == 0 && h6 == 0 && o == 0) return 0;
+if (p3 == 0 && p6 == 0 && h3 == 0 && h6 == 0) return 0;
 if (c == 0) return 0;
 answer = 100 / (1 + pc6/p6 * (1 + p3/pc3 + h3/hi3 + o/co + p6/ks)) + 100 / (1 + hc6/h6 * (1 + h3/hc3));
 if (answer <= 90 && answer >= 15) return answer;
