@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -68,9 +68,12 @@ extern int LookupNutrNo[];
 extern int LookupNut[];
 extern int FoodCount;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void initializations(void);
 int order_new_food(void);
-void order_new_food_already_sorted(void);
 int namestrcmp(char *, char *);
 int substring_finder(char *, char *);
 struct food *food_choice(char *, int);
@@ -91,4 +94,8 @@ void compute_derived_fields(struct food *);
 char *format_serving(char *, float *, struct food *);
 float n6hufa(float, float, float, float, float, float);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
