@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,8 +26,6 @@
 #include "options.h"
 #include <stdlib.h>
 
-int mealdb_mealsperday;
-
 int main(int argc, char *argv[])
 {
 food_root.next = NULL;
@@ -44,14 +42,6 @@ if ( version(0) == MAJVERSION && version(1) == MINVERSION && read_food_db() )
  read_OPTIONS(0);
  }
 else read_food_files();
-if (version(0) != MAJVERSION || version(1) != MINVERSION)
- {
- if ((version(0) == 10 && version(1) < 8) || version(0) < 10)
-  {
-  if (mealdb_mealsperday > 0 && ((version(0) == 10 && version(1) < 8) || version(0) < 10)) options.mealsperday = mealdb_mealsperday;
-  else options.mealsperday = 3;
-  }
- }
 if (version(0) != MAJVERSION || version(1) != MINVERSION) write_version();
 menu();
 exit(0);
