@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -206,29 +206,32 @@ char abcarbflag[40];
 char abfiberflag[40];
 for ( ; ; )
  {
- sprintf(calflag,"%s  %5.1f %s",(options.locknuts[ENERC_KCAL] ? "(LOCKED:" : options.autocal ? "(AUTO-SET:"  : "(SET:"),options.abnuts[ENERC_KCAL],"kc)");
+ sprintf(calflag,"%s  %5.1f %s",(options.locknuts[ENERC_KCAL] && options.autocal == 0 ? "(LOCKED:" : options.autocal > 0 ? "(AUTO-SET:"  : "(SET:"),options.abnuts[ENERC_KCAL],"kc)");
  sprintf(pcproteinflag,"%s %5.1f%s",options.locknuts[PROCNT] && options.pcprotein > 0 ? "(LOCKED:" : "(SET:",options.pcprotein,"%)");
  sprintf(pccarbflag,"%s %5.1f%s",options.locknuts[CHOCDF] && options.pccarb > 0 ? "(LOCKED:" : "(SET:",options.pccarb,"%)");
  sprintf(pcsatfatflag,"%s %5.1f%s",options.locknuts[FASAT] ? "(LOCKED:" : "(SET:",options.pcsatfat,"%)");
  sprintf(abproteinflag,"%s  %5.1f %s",options.locknuts[PROCNT] && options.abnuts[PROCNT] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[PROCNT],"g)");
- if (options.abnuts[CHOCDF] >= 0) sprintf(abcarbflag,"%s  %5.1f %s",options.locknuts[CHOCDF] && options.abnuts[CHOCDF] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[CHOCDF],"g)");
- else sprintf(abcarbflag,"%s %5.1f %s","(LOCKED:  Fiber +",-1 * options.abnuts[CHOCDF],"g)");
+ if (options.autocal == 4 || options.autocal == 5) sprintf(abproteinflag,"%s  %5.1f %s",options.locknuts[PROCNT] && options.abnuts[PROCNT] > 0 ? "(AUTO-SET:" : "(SET:",options.abnuts[PROCNT],"g)");
+ if (options.abnuts[CHOCDF] >= 0 && options.autocal < 4) sprintf(abcarbflag,"%s  %5.1f %s",options.locknuts[CHOCDF] && options.abnuts[CHOCDF] > 0 ? "(LOCKED:" : "(SET:",options.abnuts[CHOCDF],"g)");
+ else if (options.autocal < 4) sprintf(abcarbflag,"%s %5.1f %s","(LOCKED:  Fiber +",-1 * options.abnuts[CHOCDF],"g)");
+ else if (options.abnuts[CHOCDF] < 0) sprintf(abcarbflag,"%s %5.1f %s","(AUTO-SET:  Fiber +",-1 * options.abnuts[CHOCDF],"g)");
+ else sprintf(abcarbflag,"%s %5.1f %s","(AUTO-SET:  ",options.abnuts[CHOCDF],"g)");
  sprintf(abfiberflag,"%s %5.1f %s",options.locknuts[FIBTG] ? "(LOCKED:" : "(SET:",options.abnuts[FIBTG],"g)");
  header("NUT:  Personal Options");
- printf("                1  --  Change Calorie Level %s\n\n",options.abnuts[ENERC_KCAL] != 2000 || options.locknuts[ENERC_KCAL] || options.autocal ? calflag : "(default)");
- if (options.n6hufa == 0 && options.abnuts[FAPU] == 0) printf("                2  --  Essential Fatty Acid Options (default)\n\n");
- else if (options.locknuts[FAPU] == 1) printf("                2  --  Essential Fatty Acid Options (LOCKED:  %3.1f g)\n\n",options.abnuts[FAPU]);
- else if (options.n6hufa == 90 && options.abnuts[FAPU] == 0) printf("                2  --  Essential Fatty Acid Options (SET:  off)\n\n");
- else if (options.n6hufa > 0 && options.abnuts[FAPU] == 0) printf("                2  --  Essential Fatty Acid Options (SET:  %2.0f/%2.0f)\n\n",options.n6hufa,100-options.n6hufa);
- else if (options.abnuts[FAPU] > 0) printf("                2  --  Essential Fatty Acid Options (SET:  %3.1f g)\n\n",options.abnuts[FAPU]);
- printf("                3  --  Saturated Fat Percentage %s\n\n",options.pcsatfat ? pcsatfatflag : "(default)");
- printf("                4  --  Fiber Absolute Amount %s\n\n",options.abnuts[FIBTG] ? abfiberflag : "(default)");
- printf("                5  --  Carbohydrate Percentage %s\n\n",options.pccarb ? pccarbflag : "(default)");
- printf("                6  --  Protein Percentage %s\n\n",options.pcprotein ? pcproteinflag : "(default)");
- printf("                7  --  Carbohydrate Absolute Amount %s\n\n",options.abnuts[CHOCDF] ? abcarbflag : "(default)");
- printf("                8  --  Protein Absolute Amount %s\n\n",options.abnuts[PROCNT] ? abproteinflag : "(default)");
- printf("                0  --  Restore All Defaults\n\n");
- printf("                W  --  Weight Log Regression\n");
+ printf("              1  --  Change Calorie Level %s\n\n",options.abnuts[ENERC_KCAL] != 2000 || options.locknuts[ENERC_KCAL] || options.autocal > 0 ? calflag : "(default)");
+ if (options.n6hufa == 0 && options.abnuts[FAPU] == 0) printf("              2  --  Essential Fatty Acid Options (default)\n\n");
+ else if (options.locknuts[FAPU] == 1) printf("              2  --  Essential Fatty Acid Options (LOCKED:  %3.1f g)\n\n",options.abnuts[FAPU]);
+ else if (options.n6hufa == 90 && options.abnuts[FAPU] == 0) printf("              2  --  Essential Fatty Acid Options (SET:  off)\n\n");
+ else if (options.n6hufa > 0 && options.abnuts[FAPU] == 0) printf("              2  --  Essential Fatty Acid Options (SET:  %2.0f/%2.0f)\n\n",options.n6hufa,100-options.n6hufa);
+ else if (options.abnuts[FAPU] > 0) printf("              2  --  Essential Fatty Acid Options (SET:  %3.1f g)\n\n",options.abnuts[FAPU]);
+ printf("              3  --  Saturated Fat Percentage %s\n\n",options.pcsatfat ? pcsatfatflag : "(default)");
+ printf("              4  --  Fiber Absolute Amount %s\n\n",options.abnuts[FIBTG] ? abfiberflag : "(default)");
+ printf("              5  --  Carbohydrate Percentage %s\n\n",options.pccarb ? pccarbflag : "(default)");
+ printf("              6  --  Protein Percentage %s\n\n",options.pcprotein ? pcproteinflag : "(default)");
+ printf("              7  --  Carbohydrate Absolute Amount %s\n\n",options.abnuts[CHOCDF] ? abcarbflag : "(default)");
+ printf("              8  --  Protein Absolute Amount %s\n\n",options.abnuts[PROCNT] ? abproteinflag : "(default)");
+ printf("              0  --  Restore All Defaults\n\n");
+ printf("              W  --  Weight Log Regression\n");
  spacer(19);
  printf("\nEnter your choice (just <enter> to quit):  ");
  menu_choice = get_char();
