@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 
 struct opt options;
 
-static float DefaultTarget = 90, DefaultEPADHA = 0.6;
+static float DefaultTarget = 50, DefaultEPADHA = 2.4;
 
 void initialize_options()
 {
@@ -53,11 +53,14 @@ for (c=0; c < NUTRIENT_COUNT; c++)
  options.locknuts[c] = 0;
  options.abnuts[c] = 0;
  }
-if (mealdb_mealsperday > 0 && mealdb_mealsperday < 20) options.mealsperday = mealdb_mealsperday;
-else options.mealsperday = 3;
+options.mealsperday = 3;
 options.grams = 0;
 options.autocal = 0;
 options.temp_meal_root = &meal_root;
+options.lastwlw = 0;
+options.lastwlbfp = 0;
+options.lastwldate = 0;
+options.alafactor = ALA_FACTOR;
 }
 
 void personal_cal()
@@ -66,11 +69,18 @@ float buf = 0;
 int choice;
 options.abnuts[FAMS] = 0;
 header("NUT:  Set Personal Calorie Level");
-printf("\n  Calorie level is set to %0.0f.\n\n",DV[ENERC_KCAL]);
+if (options.autocal == 0 ) printf("\n  Calorie level is set to %0.0f.\n\n",DV[ENERC_KCAL]);
+else printf("\n  Calorie level is set to %0.0f.  Option is #%d.\n\n",DV[ENERC_KCAL],options.autocal + 2);
 printf("\n  1.  I will type a new calorie level.\n");
 printf("\n  2.  I want to return to the program default of 2000.\n");
 printf("\n  3.  I want NUT to automatically use the average calories from all my meals.\n");
-spacer(9);
+printf("\n  4.  When I make a daily \"Weight Log Regression\" entry, make a small calorie\n");
+printf("      adjustment to hold lean mass constant.  Take the lean mass target from\n");
+printf("      the first weight log data point that includes a body fat measurement.\n");
+printf("\n  5.  When I make a daily \"Weight Log Regression\" entry, make a small calorie\n");
+printf("      adjustment to hold fat mass constant.  Take the fat mass target from\n");
+printf("      the first weight log data point that includes a body fat measurement.\n");
+spacer(17);
 printf("\nEnter your choice (just <enter> to retain current setting):  ");
 choice = get_int();
 switch (choice)
@@ -86,7 +96,7 @@ switch (choice)
    options.locknuts[ENERC_KCAL] = 1;
    options.abnuts[ENERC_KCAL] = buf;
    }
-  options.abnuts[FAT] = 0;
+  if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
   options.abnuts[FAMS] = 0;
   options.autocal = 0;
   break;
@@ -99,10 +109,26 @@ switch (choice)
   options.abnuts[FAMS] = 0;
   options.autocal = 1;
   break;
+ case 4 :
+  options.locknuts[ENERC_KCAL] = 1;
+  options.locknuts[FAT] = 0;
+  options.abnuts[FAT] = 0;
+  options.locknuts[FAMS] = 0;
+  options.abnuts[FAMS] = 0;
+  options.autocal = 2;
+  break;
+ case 5 :
+  options.locknuts[ENERC_KCAL] = 1;
+  options.locknuts[FAT] = 0;
+  options.abnuts[FAT] = 0;
+  options.locknuts[FAMS] = 0;
+  options.abnuts[FAMS] = 0;
+  options.autocal = 3;
+  break;
  case 2 :
   options.locknuts[ENERC_KCAL] = 0;
   options.abnuts[ENERC_KCAL] = 0;
-  options.abnuts[FAT] = 0;
+  if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
   options.abnuts[FAMS] = 0;
   options.autocal = 0;
   break;
@@ -129,10 +155,11 @@ while (1)
  else printf("           1.  Allow reference values to change with analysis resets.\n\n");
  if (options.locknuts[FAPU] != 1) printf("           2.  Change target for Omega-6/3 Balance (currently %2.0f/%2.0f).\n\n",options.n6hufa == 0 ? DefaultTarget : options.n6hufa,options.n6hufa == 0 ? 100 - DefaultTarget : 100 - options.n6hufa);
  if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
- if (options.locknuts[FAPU] != 1) printf("\n\n\n      If you change options #2 or #3, you will have to reset the analysis\n");
+ if (options.locknuts[FAPU] != 1) printf("           4.  Change LA:ALA ratio (currently %1.0g:1).\n\n",options.alafactor);
+ if (options.locknuts[FAPU] != 1) printf("\n\n\n      If you change options, you will have to reset the analysis\n");
  if (options.locknuts[FAPU] != 1) printf("      screen with a \"c\", \"m\", or \"o\" to have the new settings take effect.\n");
- if (options.locknuts[FAPU] != 1) spacer(13);
- else spacer(4);
+ if (options.locknuts[FAPU] != 1) spacer(15);
+ else spacer(6);
  printf("\nEnter your choice (just <enter> to quit):  ");
  menu_choice = get_char();
  switch (menu_choice)
@@ -149,8 +176,9 @@ while (1)
   else printf("           1.  Allow reference values to change with analysis resets.\n\n");
   if (options.locknuts[FAPU] != 1) printf("           2.  Change target for Omega-6/3 Balance (currently %2.0f/%2.0f).\n\n",options.n6hufa == 0 ? DefaultTarget : options.n6hufa,options.n6hufa == 0 ? 100 - DefaultTarget : 100 - options.n6hufa);
   if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
-  if (options.locknuts[FAPU] != 1) spacer(8);
-  else spacer(4);
+ if (options.locknuts[FAPU] != 1) printf("           4.  Change LA:ALA ratio (currently %1.0g:1).\n\n",options.alafactor);
+  if (options.locknuts[FAPU] != 1) spacer(10);
+  else spacer(6);
   printf("\nEnter new Omega-6 percentage (15-90, 90 = off):  ");
   get_string(buf,127);
   tempfloat = atof(buf);
@@ -166,8 +194,9 @@ while (1)
   else printf("           1.  Allow reference values to change with analysis resets.\n\n");
   if (options.locknuts[FAPU] != 1) printf("           2.  Change target for Omega-6/3 Balance (currently %2.0f/%2.0f).\n\n",options.n6hufa == 0 ? DefaultTarget : options.n6hufa,options.n6hufa == 0 ? 100 - DefaultTarget : 100 - options.n6hufa);
   if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
-  if (options.locknuts[FAPU] != 1) spacer(8);
-  else spacer(4);
+ if (options.locknuts[FAPU] != 1) printf("           4.  Change LA:ALA ratio (currently %1.0g:1).\n\n",options.alafactor);
+  if (options.locknuts[FAPU] != 1) spacer(10);
+  else spacer(6);
   printf("\nEnter new EPA+DHA maximum grams:  ");
   get_string(buf,127);
   tempfloat = atof(buf);
@@ -176,6 +205,24 @@ while (1)
   write_OPTIONS();
   break; 
 
+  case '4' : 
+  header("NUT:  Essential Fatty Acid Options");
+  printf("\n\n");
+  if (options.locknuts[FAPU] != 1) printf("           1.  Accept current reference values as absolute amounts.\n\n");
+  else printf("           1.  Allow reference values to change with analysis resets.\n\n");
+  if (options.locknuts[FAPU] != 1) printf("           2.  Change target for Omega-6/3 Balance (currently %2.0f/%2.0f).\n\n",options.n6hufa == 0 ? DefaultTarget : options.n6hufa,options.n6hufa == 0 ? 100 - DefaultTarget : 100 - options.n6hufa);
+  if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
+ if (options.locknuts[FAPU] != 1) printf("           4.  Change LA:ALA ratio (currently %1.0g:1).\n\n",options.alafactor);
+  if (options.locknuts[FAPU] != 1) spacer(10);
+  else spacer(6);
+  printf("\nEnter new LA factor:  ");
+  get_string(buf,127);
+  tempfloat = atof(buf);
+  if (tempfloat <= 0) break;
+  else options.alafactor = tempfloat;
+  write_OPTIONS();
+  break; 
+
   default  : return;
   }
  }
@@ -185,7 +232,7 @@ void efa_method()
 {
 if (options.locknuts[FAPU] == 1)
  {
- options.abnuts[FAT] = 0;
+ if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
  options.abnuts[FAMS] = 0;
  options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
  options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
@@ -227,8 +274,7 @@ if ( options.pcprotein > 0 )
  options.abnuts[PROCNT] = 0;
  options.locknuts[PROCNT] = 1;
  }
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -251,8 +297,7 @@ if ( options.pccarb <= 0 || (options.pcprotein + options.pccarb) > 90 )
  options.locknuts[CHOCDF] = 0;
  }
 if ( options.pccarb > 0 ) options.abnuts[CHOCDF] = 0;
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -275,7 +320,7 @@ if ( options.pcsatfat <= 0  || options.pcsatfat > 90 )
  options.locknuts[FASAT] = 0;
  options.abnuts[FASAT] = 0;
  }
-options.abnuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -301,8 +346,7 @@ if ( options.abnuts[PROCNT] > 0 )
  options.pcprotein = 0;
  options.locknuts[PROCNT] = 1;
  }
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -325,8 +369,7 @@ if ( options.abnuts[CHOCDF] != 0 )
  options.pccarb = 0;
  options.locknuts[CHOCDF] = 1;
  }
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -379,7 +422,7 @@ void auto_cal(float *bufptr, int analflag)
 {
 float buf = *bufptr, temp = 0;
 int i;
-if (options.autocal) buf = average_cals();
+if (options.autocal == 1) buf = average_cals();
 if (analflag)
  {
  if (food_work.nutrient[PROT_KCAL] > 0 && food_work.nutrient[PROCNT] > 0) options.protcalpergm = food_work.nutrient[PROT_KCAL] / food_work.nutrient[PROCNT];
@@ -396,6 +439,7 @@ if (buf <= 0)
  }
 else if (buf > 0 && buf <= 100) buf = 100;
 else if (buf > 9999) buf = 9999;
+else if (options.abnuts[FAT] && analflag) buf -= (food_work.nutrient[FAT] - options.abnuts[FAT]) * options.fatcalpergm;
 buf /= DVBase[ENERC_KCAL];
 DV[ENERC_KCAL] = buf * DVBase[ENERC_KCAL];
 if (buf != 1)
@@ -584,6 +628,7 @@ if ( removelock )
  {
  options.autocal = 0;
  options.n6hufa = 0;
+ options.alafactor = ALA_FACTOR;
  options.epadhamax = 0;
  }
 for ( i = 0; i < NUTRIENT_COUNT ; i++ ) if ( !options.locknuts[i] ) options.abnuts[i] = 0;
@@ -603,12 +648,14 @@ if (options.n6hufa != 0)
  if (options.n6hufa < 15) options.n6hufa = 15;
  if (options.n6hufa > 90) options.n6hufa = 90;
  }
+
+if (options.alafactor <= 0) options.alafactor = ALA_FACTOR;
   
 if (options.epadhamax <= 0) epadhalimit = DefaultEPADHA;
 else epadhalimit = options.epadhamax;
 
-options.abnuts[ALA] = food_work.nutrient[ALA];
-if (options.abnuts[ALA] < DV[ALA]) options.abnuts[ALA] = DV[ALA];
+options.abnuts[ALA] = food_work.nutrient[LA] / options.alafactor;
+if (options.abnuts[ALA] < food_work.nutrient[ALA]) options.abnuts[ALA] = food_work.nutrient[ALA];
 extra_ala = options.abnuts[ALA] - food_work.nutrient[ALA];
 
 if ( (DefaultTarget == 90 && options.n6hufa == 0) || options.n6hufa == 90 || options.n6hufa == 15)
@@ -729,7 +776,7 @@ else
 void weight_log()
 {
 char newentry[128];
-int n, nfat;
+int n, nfat, justmadenewentry = 0;
 float weightslope, fatslope;
 float weight, bf, stardate;
 time_t t;
@@ -738,6 +785,21 @@ while (1)
  {
  header("NUT:  Weight Log Regression");
  read_WLOG(&n,&nfat,&weightslope,&fatslope);
+ if (justmadenewentry && options.autocal > 1 && nfat > 1)
+  {
+  if (options.autocal == 3)
+   {
+   if (options.lastwlbfp * options.lastwlw / 100 > options.fattarget) options.abnuts[ENERC_KCAL] -= 20;
+   else options.abnuts[ENERC_KCAL] += 20;
+   }
+  else if (options.autocal == 2)
+   {
+   if (options.lastwlw - (options.lastwlbfp * options.lastwlw / 100) > options.leantarget) options.abnuts[ENERC_KCAL] -= 20;
+   else options.abnuts[ENERC_KCAL] += 20;
+   }
+  auto_cal(&options.abnuts[ENERC_KCAL],0);
+  }
+ justmadenewentry = 0;
  printf("\n\n");
  printf("                           data points:   %6d\n",n);
  printf("\n\n");
@@ -777,6 +839,7 @@ while (1)
    {
    weight   = atof(strtok(newentry," "));
    bf       = atof(strtok(NULL," "));
+   justmadenewentry = 1;
    }
   stardate = ((float) t / 86400) - 14486;
   if (weight > 0) write_WLOG(&weight,&bf,&stardate);
