@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,7 +41,13 @@ struct opt
  float fatcalpergm;
  float fattyacidfactor;
  float n6hufa;
+ float alafactor;
  float epadhamax;
+ float lastwlw;
+ float lastwlbfp;
+ float lastwldate;
+ float fattarget;
+ float leantarget;
  int next_recipe;
  int locknuts[NUTRIENT_COUNT];
  float abnuts[NUTRIENT_COUNT];
@@ -51,6 +57,8 @@ struct opt
  struct meal *temp_meal_root;
  };
 
+#define ALA_FACTOR 7
+
 #define DELOPT        1000 
 #define DEFANAL       1001
 #define SCREEN        1002
@@ -67,9 +75,15 @@ struct opt
 #define FATCALPERGM   1014
 #define FATTYACIDFACTOR 1015
 #define N6HUFA        1016
+#define ALAFACTOR     1017
 #define EPADHAMAX     1018
 #define DEFANALANAL   1019
 #define DEFANALREC    1020
+#define LASTWLW       1021
+#define LASTWLBFP     1022
+#define LASTWLDATE    1023
+#define FATTARGET     1024
+#define LEANTARGET    1025
 
 #define OPT_CHO_NONFIB 2000
 #define OPT_LA         2001
@@ -82,7 +96,10 @@ struct opt
 #define OPT_VITE       2008
 
 extern struct opt options;
-extern int mealdb_mealsperday;
+
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 void initialize_options(void);
 void personal_cal(void);
@@ -104,4 +121,8 @@ void restore_defaults(int);
 void efa_dynamics();
 void weight_log();
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+ 
 #endif
