@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +22,16 @@
 #ifndef RECMEAL_H
 #define RECMEAL_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void record_meals(void);
 void today(char *);
 void time_machine(char *);
 
+#ifdef __cplusplus
+} /* closing brace for extern "C" */
+#endif
+
 #endif
